@@ -1,5 +1,8 @@
 import re
 
+from docutils import nodes
+from sphinx import addnodes
+
 
 def autodoc_skip_member(app, what, name, obj, skip, options):
     if (
@@ -8,6 +11,8 @@ def autodoc_skip_member(app, what, name, obj, skip, options):
         and name
         in ("__init__", "__eq__", "__ne__", "__lt__", "__le__", "__call__")
         and obj.__doc__
+        and getattr(obj, "__objclass__", None)
+        not in (type, object, list, tuple, dict)
     ):
         return False
     else:
@@ -29,6 +34,66 @@ _track_autodoced = {}
 _inherited_names = set()
 
 
+def _superclass_classstring(
+    adjusted_mod, base, tilde=False, pytype="class", attrname=None
+):
+
+    dont_link = (
+        base.__module__ == "builtins"
+        or base.__name__.startswith("_")
+        or (attrname and attrname.startswith("_"))
+    )
+    attrname = ".%s" % attrname if attrname else ""
+    if dont_link:
+        return "``%s.%s%s``" % (adjusted_mod, base.__name__, attrname)
+    else:
+        return ":%s:`%s%s.%s%s`" % (
+            pytype,
+            "~" if tilde else "",
+            adjusted_mod,
+            base.__name__,
+            attrname,
+        )
+
+
+def fix_up_autodoc_headers(app, doctree):
+
+    for idx, node in enumerate(doctree.traverse(addnodes.desc)):
+        objtype = node.attributes.get("objtype")
+        if objtype in ("method", "attribute"):
+            sig = node.children[0]
+
+            modname = sig.attributes["module"]
+            clsname = sig.attributes["class"]
+            qualified = "%s.%s." % (modname, clsname)
+
+            sig.insert(
+                0,
+                nodes.reference(
+                    "",
+                    "",
+                    nodes.literal(qualified, qualified),
+                    refid="%s.%s" % (modname, clsname),
+                ),
+            )
+
+            sig.insert(
+                0,
+                addnodes.desc_annotation(
+                    objtype, nodes.Text(objtype + " ", objtype + " ")
+                ),
+            )
+
+        elif objtype == "function":
+            sig = node.children[0]
+            sig.insert(
+                0,
+                addnodes.desc_annotation(
+                    objtype, nodes.Text(objtype + " ", objtype + " ")
+                ),
+            )
+
+
 def autodoc_process_docstring(app, what, name, obj, options, lines):
     if what == "class":
         _track_autodoced[name] = obj
@@ -42,7 +107,7 @@ def autodoc_process_docstring(app, what, name, obj, options, lines):
                 adjusted_mod = _adjust_rendered_mod_name(
                     app.env.config, base.__module__, base.__name__
                 )
-                bases.append(":class:`%s.%s`" % (adjusted_mod, base.__name__))
+                bases.append(_superclass_classstring(adjusted_mod, base))
                 _inherited_names.add("%s.%s" % (adjusted_mod, base.__name__))
 
         if bases:
@@ -73,15 +138,21 @@ def autodoc_process_docstring(app, what, name, obj, options, lines):
                         ".. container:: inherited_member",
                         "",
                         "    *inherited from the* "
-                        ":%s:`~%s.%s.%s` *%s of* :class:`~%s.%s`"
+                        "%s *%s of* %s"
                         % (
-                            "attr" if what == "attribute" else "meth",
-                            adjusted_mod,
-                            supercls.__name__,
-                            attrname,
+                            _superclass_classstring(
+                                adjusted_mod,
+                                supercls,
+                                attrname=attrname,
+                                pytype="attr"
+                                if what == "attribute"
+                                else "meth",
+                                tilde=True,
+                            ),
                             what,
-                            adjusted_mod,
-                            supercls.__name__,
+                            _superclass_classstring(
+                                adjusted_mod, supercls, tilde=True
+                            ),
                         ),
                         "",
                     ]
@@ -114,6 +185,7 @@ def setup(app):
 
     app.connect("autodoc-skip-member", autodoc_skip_member)
     app.connect("autodoc-process-docstring", autodoc_process_docstring)
+    app.connect("doctree-read", fix_up_autodoc_headers)
     app.add_config_value("autodocmods_convert_modname", {}, "env")
     app.add_config_value("autodocmods_convert_modname_w_class", {}, "env")
 
